@@ -34,12 +34,11 @@ from scipy.cluster import hierarchy as hrc
 from scipy.spatial.distance import pdist, cdist
 from scipy.cluster.hierarchy import dendrogram, linkage
 
+# CHECK IF THESE ARE USED
+
 import sklearn
 from sklearn.decomposition import PCA
-from sklearn.decomposition import KernelPCA
 from sklearn.manifold import TSNE
-from sklearn.decomposition import NMF
-from sklearn.linear_model import Ridge, Lasso
 
 from umap import UMAP
 import matplotlib.pyplot as plt
@@ -378,8 +377,6 @@ class Forest:
     Methods that summarize the factors, usually in matrix form.
     """
 
-
-
     def factor_partial_matrix(self, features=None):
         if features is None:
             coordinates = np.zeros(
@@ -396,7 +393,6 @@ class Forest:
         return coordinates
 
     def factor_feature_matrix(self, features=None):
-
         """
         Average additive gain across all nodes in all factors, in array form.
 
@@ -418,7 +414,6 @@ class Forest:
         return coordinates
 
     def factor_mean_matrix(self, features=None):
-
         """
         Arguments:
         features = Selects a small subset of features to look at instead of all features.
@@ -443,17 +438,16 @@ class Forest:
                     coordinates[i, j] = split_cluster.feature_mean(feature)
         return coordinates
 
+    ########################################################################
+    ########################################################################
 
-########################################################################
-########################################################################
+    # LOADING/CREATION METHODS
 
-# LOADING/CREATION METHODS
+    # This section deals with methods that load and unload the forest
+    # from disk
 
-# This section deals with methods that load and unload the forest
-# from disk
-
-########################################################################
-########################################################################
+    ########################################################################
+    ########################################################################
 
     def backup(self, location):
         print("Saving forest")
@@ -640,12 +634,10 @@ class Forest:
                 for feature in removed_features:
                     self.remove_output_feature(feature)
 
-
     def predict(self, matrix):
         prediction = Prediction(self, matrix)
         return prediction
 
-
     def split_labels(self, depth=3):
 
         nodes = self.nodes(depth=depth)
@@ -691,10 +683,6 @@ class Forest:
 
     def cluster_samples_encoding(self, override=False, pca=None, depth=None, resolution=1, **kwargs):
 
-        # Todo: remove this hack
-        if depth is not None:
-            depth_limit = depth
-
         if hasattr(self, 'sample_labels') and override:
             self.reset_sample_clusters()
 
@@ -757,18 +745,6 @@ class Forest:
         for leaf, label in zip(leaves, self.leaf_labels):
             leaf.leaf_cluster = label
 
-    def cluster_leaves_predictions(self, override=False, mode='mean', *args, **kwargs):
-
-        leaves = self.leaves()
-        predictions = self.node_representation(leaves, mode=mode)
-
-        if hasattr(self, 'leaf_clusters') and not override:
-            print("Clustering has already been done")
-            return self.leaf_labels
-        else:
-            self.set_leaf_labels(sdg.fit_predict(predictions, *args, **kwargs))
-
-        return self.leaf_labels
 
     def node_change_absolute(self, nodes1, nodes2):
         # First we obtain the medians for the nodes in question
@@ -848,7 +824,6 @@ class Forest:
         nodes = np.array(self.nodes(root=True, depth=depth))
 
         stem_mask = np.array([n.level != 0 for n in nodes])
-        root_mask = np.logical_not(stem_mask)
 
         labels = np.zeros(len(nodes)).astype(dtype=int)
 
@@ -895,7 +870,7 @@ class Forest:
         clusters = []
 
         if not roots:
-            labels = [l+1 for l in labels]
+            labels = [l + 1 for l in labels]
 
         for node, label in zip(nodes, labels):
             node.set_split_cluster(label)
@@ -1051,8 +1026,7 @@ class Forest:
                 cluster.id for cluster in self.split_clusters]
 
         cluster_names = [cluster.name() for cluster in self.split_clusters]
-        cluster_coordiantes = combined_coordinates[-1 *
-                                                   len(self.split_clusters):]
+        cluster_coordiantes = combined_coordinates[-1 * len(self.split_clusters):]
 
         f = plt.figure(figsize=(5, 5))
         plt.title("TSNE-Transformed Sample Coordinates")
@@ -1068,7 +1042,6 @@ class Forest:
     def plot_representation(self, representation, labels=None, metric='cos', pca=False):
 
         if metric is not None:
-            # image = reduction[split_order].T[split_order].T
             agg_f = dendrogram(linkage(
                 representation, metric=metric, method='average'), no_plot=True)['leaves']
             agg_s = dendrogram(linkage(
@@ -1110,11 +1083,9 @@ class Forest:
         coordinates = np.zeros((len(self.sample_clusters), len(features)))
         for i, sample_cluster in enumerate(self.sample_clusters):
             for j, feature in enumerate(features):
-                # coordinates[i,j] = sample_cluster.feature_median(feature)
                 coordinates[i, j] = sample_cluster.feature_mean(feature)
         return coordinates
 
-
     def tsne(self, no_plot=False, pca=100, override=False, **kwargs):
         if not hasattr(self, 'tsne_coordinates') or override:
             if pca:
@@ -1197,7 +1168,7 @@ class Forest:
 
     def coordinates(self, override=False, type=None, scaled=True, **kwargs):
 
-        if hasattr(self,'coordinate_cache') and not override:
+        if hasattr(self, 'coordinate_cache') and not override:
             return self.coordinate_cache
 
         if type is None:
@@ -1219,7 +1190,7 @@ class Forest:
 
         return coordinates
 
-    def set_coordiantes(self,coordinates):
+    def set_coordiantes(self, coordinates):
         self.coordinate_type = 'precomputed'
         self.coordinate_cache = coordinates
 
@@ -1261,15 +1232,13 @@ class Forest:
 
         return f
 
+    ########################################################################
+    ########################################################################
 
-########################################################################
-########################################################################
-
-# Consensus tree methods
-
-########################################################################
-########################################################################
+    # Consensus tree methods
 
+    ########################################################################
+    ########################################################################
 
     def split_cluster_transition_matrix(self, depth=3):
 
@@ -1349,7 +1318,6 @@ class Forest:
     def split_cluster_odds_ratios(self):
 
         cluster_populations = [len(c.nodes) for c in self.split_clusters]
-        total_nodes = np.sum(cluster_populations)
 
         downstream_frequency = np.ones(
             (len(self.split_clusters), len(self.split_clusters)))
@@ -1377,18 +1345,20 @@ class Forest:
 
         return odds_ratio
 
-    ###############
-    # Here we have several alternative methods for constructing the consensus tree.
-    ###############
+=======
 
-    # Most of them depend on these two helper methods that belong only in this scope
+    ########################################################################
+    # Consensus tree helper methods
+    ########################################################################
 
-    # The finite tree method takes a prototype, which is a list of lists.
-    # Each element in the list corresponds to which elements consider this element their parent
+    """
+    Most of them depend on these two helper methods that belong only in this scope
+
+    The finite tree method takes a prototype, which is a list of lists.
+    Each element in the list corresponds to which elements consider this element their parent
+    """
 
     def finite_tree(cluster, prototype, available):
-        print(cluster)
-        print(prototype)
         children = []
         try:
             available.remove(cluster)
@@ -1411,8 +1381,6 @@ class Forest:
         child_entries[root] = []
         return child_entries
 
-    # End helpers
-
     def most_likely_tree(self, depth=3, transitions=None):
 
         if transitions is None:
@@ -1435,7 +1403,6 @@ class Forest:
         print(f"Transition mtx shape: {transitions.shape}")
 
         tree = []
-        # entry = np.argmax(transitions[-1])
         entry = 0
 
         tree = Forest.finite_tree(
@@ -1451,12 +1418,11 @@ class Forest:
 
         if mode == "transition_matrix":
             distances = self.split_cluster_transition_matrix(depth=depth)
-            # np.diag(distances) = 0
             distances[:, -1] = 0
         elif mode == "odds_ratio":
-            distance = 1. / self.split_cluster_odds_ratios()
+            distances = 1. / self.split_cluster_odds_ratios()
         elif mode == "dependence":
-            distance = self.partial_dependence()
+            distances = self.partial_dependence()
         elif mode == "means":
             mean_matrix = self.split_cluster_mean_matrix()
             domain_matrix = self.split_cluster_domain_mean_matrix()
@@ -1501,11 +1467,9 @@ class Forest:
 
         return tree
 
-
-#########################################################
-# HTML Visualization methods
-#########################################################
-
+    #########################################################
+    # HTML Visualization methods
+    #########################################################
 
     def html_directory(self):
 
@@ -1519,12 +1483,10 @@ class Forest:
 
     def html_tree_summary(self, n=3, mode="ud", custom=None, labels=None, features=None, primary=True, cmap='viridis', secondary=True, figsize=(30, 30), output=None):
 
-
         if n > (self.output.shape[1] / 2):
             print("WARNING, PICKED N THAT IS TOO LARGE, SETTING LOWER")
             n = max(int(self.output.shape[1] / 2), 1)
 
-
         # First we'd like to make sure we are operating from scratch in the html directory:
         if output is None:
             location = self.location()
@@ -1633,9 +1595,6 @@ class Forest:
 
             if primary:
 
-                # print(f"Coordinates:{coordinates}")
-                # print(f"Flat tree:{flat_tree}")
-
                 primary_connections = []
 
                 for i, children in flat_tree:
@@ -1703,7 +1662,7 @@ class Forest:
 
             # Now we need to loop over available clusters to place the cluster decorations into the template
 
-            for i,cj in enumerate(cluster_jsons):
+            for i, cj in enumerate(cluster_jsons):
                 cluster_summary_html = f"<script> summaries['cluster_{i}'] = {cj};</script>"
                 html_report.write(cluster_summary_html)
 
@@ -1761,8 +1720,6 @@ class Forest:
 
         return correlations
 
-
-
 class TruthDictionary:
 
     def __init__(self, counts, header, samples=None):
@@ -1780,10 +1737,4 @@ class TruthDictionary:
             self.sample_dictionary[sample.strip("''").strip('""')] = i
 
     def look(self, sample, feature):
-        #         print(feature)
         return(self.counts[self.sample_dictionary[sample], self.feature_dictionary[feature]])
-
-
-if __name__ != "__main__":
-    import matplotlib as mpl
-    mpl.rcParams['figure.dpi'] = 300
